/*
 * PrlApiMacro.h
 *
 * Copyright (c) 1999-2017, Parallels International GmbH
 * Copyright (c) 2017-2019 Virtuozzo International GmbH. All rights reserved.
 *
 * This file is part of Virtuozzo SDK. Virtuozzo SDK is free
 * software; you can redistribute it and/or modify it under the
 * terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation; either version 2.1 of the License,
 * or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library.  If not, see
 * <http://www.gnu.org/licenses/> or write to Free Software Foundation,
 * 51 Franklin Street, Fifth Floor Boston, MA 02110, USA.
 *
 * Our contact details: Virtuozzo International GmbH, Vordergasse 59, 8200
 * Schaffhausen, Switzerland; http://www.virtuozzo.com/.
 */

/*
   In some situations we need a complete list of the API library
   functions to be accessible in one easy step. A good example
   would be the dynamic loading of the library. It seems like a
   good idea to keep such a list declared in a single file. This
   will make the future code support easier. The PrlApiMacro.h
   \file serves this purpose. The following steps illustrate how
   this file can be used:
     1. Define your own PRL_SDK_WRAP_FOR_EACH_ITERATOR:
   \#define PRL_SDK_WRAP_FOR_EACH_ITERATOR( method )
     2. Include the PrlApiMacro.h file in your source:
   \#include "PrlApiMacro.h"
     3. Instantiate the PRL_SDK_WRAP_FOR_EACH( ) macro to
        execute your specific action for each API method.
   Note
   This file contains just a list of names. No static/dynamic
   type information declared here at all.
*/

#ifndef PRL_SDK_WRAP_FOR_EACH

#include "PrlApiDeprMacro.h"

#define PRL_SDK_WRAP_FOR_EACH() \
PRL_SDK_WRAP_FOR_EACH_DEPRECATED() \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlApi_Init ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlApi_InitEx ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlApi_Deinit ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlApi_GetVersion ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlApi_GetAppMode ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlApi_GetResultDescription ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlApi_GetMessageType ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlApi_MsgCanBeIgnored ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlApi_GetCrashDumpsPath ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlApi_InitCrashHandler ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlBuffer_Free ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlApi_CreateStringsList ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlApi_CreateHandlesList ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlApi_CreateOpTypeList ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlApi_GetSupportedOsesTypes ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlApi_GetSupportedOsesVersions ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlApi_GetDefaultOsVersion ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlApi_SendProblemReport ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlApi_SendPackedProblemReport ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlStrList_GetItemsCount ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlStrList_AddItem ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlStrList_GetItem ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlStrList_RemoveItem ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlHndlList_GetItemsCount ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlHndlList_AddItem ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlHndlList_GetItem ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlHndlList_RemoveItem ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlOpTypeList_GetItemsCount ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlOpTypeList_AddItem ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlOpTypeList_GetItem ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlOpTypeList_RemoveItem ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlOpTypeList_GetTypeSize ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlApi_GetRecommendMinVmMem ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlHandle_AddRef ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlHandle_Free ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlHandle_GetType ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlDbg_GetHandlesNum ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlDbg_PrlResultToString ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlDbg_HandleTypeToString ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlDbg_EventTypeToString ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlJob_Wait ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlJob_Cancel ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlJob_GetStatus ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlJob_GetProgress ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlJob_GetRetCode ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlJob_GetDataPtr ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlJob_GetResult ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlJob_GetError ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlJob_GetOpCode ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlJob_IsRequestWasSent ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlResult_GetParamsCount ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlResult_GetParamByIndex ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlResult_GetParam ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlResult_GetParamByIndexAsString ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlResult_GetParamAsString ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlEvent_GetType ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlEvent_GetDataPtr ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlEvent_GetServer ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlEvent_GetVm ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlEvent_GetJob ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlEvent_GetParamsCount ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlEvent_GetParam ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlEvent_GetParamByName ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlEvent_GetErrCode ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlEvent_GetErrString ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlEvent_CanBeIgnored ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlEvent_IsAnswerRequired ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlEvent_GetIssuerType ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlEvent_GetIssuerId ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlEvent_CreateAnswerEvent ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlEvtPrm_GetName ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlEvtPrm_GetType ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlEvtPrm_ToString ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlEvtPrm_ToCData ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlEvtPrm_ToUint32 ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlEvtPrm_ToInt32 ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlEvtPrm_ToUint64 ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlEvtPrm_ToInt64 ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlEvtPrm_ToBoolean ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlEvtPrm_ToHandle ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlEvtPrm_GetBuffer ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlSrv_Create ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlSrv_Login ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlSrv_LoginLocal ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlSrv_Logoff ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlSrv_RegEventHandler ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlSrv_UnregEventHandler ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlSrv_GetQuestions ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlSrv_SetNonInteractiveSession ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlSrv_IsNonInteractiveSession ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlSrv_DisableConfirmationMode ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlSrv_EnableConfirmationMode ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlSrv_IsConfirmationModeEnabled ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlSrv_GetSrvConfig ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlSrv_GetCommonPrefs ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlSrv_CommonPrefsBeginEdit ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlSrv_CommonPrefsCommit ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlSrv_CommonPrefsCommitEx ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlSrv_GetUserProfile ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlSrv_GetUserInfoList ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlSrv_GetUserInfo ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlSrv_GetVirtualNetworkList ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlSrv_AddVirtualNetwork ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlSrv_UpdateVirtualNetwork ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlSrv_DeleteVirtualNetwork ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlOffmgmtService_Create ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlOffmgmtService_GetName ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlOffmgmtService_SetName ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlOffmgmtService_GetPort ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlOffmgmtService_SetPort ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlOffmgmtService_IsUsedByDefault ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlOffmgmtService_SetUsedByDefault ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlSrv_UpdateOfflineService ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlSrv_DeleteOfflineService ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlSrv_GetOfflineServicesList ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlNetworkClass_Create ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlNetworkClass_GetClassId ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlNetworkClass_SetClassId ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlNetworkClass_GetNetworkList ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlNetworkClass_SetNetworkList ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlSrv_UpdateNetworkClassesList ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlSrv_GetNetworkClassesList ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlNetworkShapingEntry_Create ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlNetworkShapingEntry_GetClassId ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlNetworkShapingEntry_SetClassId ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlNetworkShapingEntry_GetTotalRate ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlNetworkShapingEntry_SetTotalRate ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlNetworkShapingEntry_SetDevice ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlNetworkShapingEntry_GetDevice) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlNetworkShapingEntry_SetRate ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlNetworkShapingEntry_GetRate ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlNetworkShapingEntry_SetRateMPU ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlNetworkShapingEntry_GetRateMPU ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlSrv_UpdateNetworkShapingConfig ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlSrv_GetNetworkShapingConfig ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlNetworkShapingConfig_IsEnabled ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlNetworkShapingConfig_SetEnabled ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlNetworkShapingConfig_GetNetworkShapingList ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlNetworkShapingConfig_SetNetworkShapingList ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlNetworkShapingBandwidthEntry_Create ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlNetworkShapingBandwidthEntry_SetDevice ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlNetworkShapingBandwidthEntry_GetDevice ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlNetworkShapingBandwidthEntry_SetBandwidth ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlNetworkShapingBandwidthEntry_GetBandwidth) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlNetworkShapingConfig_GetNetworkDeviceBandwidthList ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlNetworkShapingConfig_SetNetworkDeviceBandwidthList ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlNetworkRate_Create ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlNetworkRate_GetClassId ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlNetworkRate_GetRate ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmCfg_SetNetworkRateList ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmCfg_GetNetworkRateList ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmCfg_IsRateBound ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmCfg_SetRateBound ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmCfg_SetOsTemplate ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmCfg_GetOsTemplate ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmCfg_ApplyConfigSample ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmCfg_GetAppTemplateList ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmCfg_SetAppTemplateList ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlSrv_ConfigureGenericPci ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlSrv_GetStatistics ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlSrv_UserProfileBeginEdit ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlSrv_UserProfileCommit ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlSrv_IsConnected ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlSrv_GetServerInfo ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlSrv_RegisterVm ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlSrv_RegisterVmEx ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlSrv_RegisterVmWithUuid ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlSrv_Register3rdPartyVm ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlSrv_CreateVm ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlSrv_GetVmList ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlSrv_GetVmListEx ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlSrv_GetDefaultVmConfig) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlSrv_CreateVmBackup ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlSrv_RestoreVmBackup ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlSrv_GetBackupTree ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlSrv_RemoveVmBackup ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlSrv_SubscribeToHostStatistics ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlSrv_UnsubscribeFromHostStatistics ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlSrv_Shutdown ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlSrv_ShutdownEx ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlSrv_FsGetDiskList ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlSrv_FsGetDirEntries ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlSrv_FsCreateDir ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlSrv_FsRemoveEntry ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlSrv_FsCanCreateFile ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlSrv_FsRenameEntry ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlSrv_UpdateLicense ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlSrv_UpdateLicenseEx ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlSrv_GetLicenseInfo ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlSrv_SendAnswer ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlSrv_StartSearchVms ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlFsInfo_GetType ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlFsInfo_GetFsType ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlFsInfo_GetChildEntriesCount ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlFsInfo_GetChildEntry ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlFsInfo_GetParentEntry ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlFsEntry_GetAbsolutePath ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlFsEntry_GetRelativeName ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlFsEntry_GetLastModifiedDate ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlFsEntry_GetSize ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlFsEntry_GetPermissions ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlFsEntry_GetType ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlSrv_NetServiceStart ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlSrv_NetServiceStop ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlSrv_NetServiceRestart ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlSrv_NetServiceRestoreDefaults ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlSrv_GetNetServiceStatus ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlSrv_GetProblemReport ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlSrv_GetPackedProblemReport ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlSrv_AttachToLostTask ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlSrv_GetSupportedOses ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlSrvCfg_GetHostRamSize ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlSrvCfg_GetCpuModel ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlSrvCfg_GetCpuCount ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlSrvCfg_GetCpuSpeed ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlSrvCfg_GetCpuMode ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlSrvCfg_GetCpuHvt ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlSrvCfg_GetCpuFeaturesEx ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlSrvCfg_GetCpuFeaturesMaskingCapabilities ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlSrvCfg_GetHostOsType ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlSrvCfg_GetHostOsMajor ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlSrvCfg_GetHostOsMinor ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlSrvCfg_GetHostOsSubMinor ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlSrvCfg_GetHostOsStrPresentation ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlSrvCfg_IsSoundDefaultEnabled ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlSrvCfg_IsUsbSupported ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlSrvCfg_IsVtdSupported ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlSrvCfg_GetMaxHostNetAdapters ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlSrvCfg_GetMaxVmNetAdapters ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlSrvCfg_GetHostname ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlSrvCfg_GetDefaultGateway ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlSrvCfg_GetDefaultGatewayIPv6 ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlSrvCfg_GetDnsServers ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlSrvCfg_GetSearchDomains ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlSrvCfg_GetFloppyDisksCount ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlSrvCfg_GetFloppyDisk ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlSrvCfg_GetOpticalDisksCount ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlSrvCfg_GetOpticalDisk ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlSrvCfg_GetSerialPortsCount ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlSrvCfg_GetSerialPort ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlSrvCfg_GetParallelPortsCount ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlSrvCfg_GetParallelPort ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlSrvCfg_GetSoundOutputDevsCount ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlSrvCfg_GetSoundOutputDev ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlSrvCfg_GetSoundMixerDevsCount ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlSrvCfg_GetSoundMixerDev ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlSrvCfg_GetPrintersCount ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlSrvCfg_GetPrinter ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlSrvCfg_GetGenericPciDevicesCount ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlSrvCfg_GetGenericPciDevice ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlSrvCfg_GetGenericScsiDevicesCount ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlSrvCfg_GetGenericScsiDevice ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlSrvCfg_GetUsbDevsCount ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlSrvCfg_GetUsbDev ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlSrvCfg_GetHardDisksCount ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlSrvCfg_GetHardDisk ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlSrvCfg_GetNetAdaptersCount ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlSrvCfg_GetNetAdapter ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlSrvCfgDev_GetName ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlSrvCfgDev_GetId ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlSrvCfgDev_GetType ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlSrvCfgDev_IsConnectedToVm ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlSrvCfgDev_GetDeviceState ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlSrvCfgDev_SetDeviceState ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlSrvCfgHdd_GetDevName ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlSrvCfgHdd_GetDevId ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlSrvCfgHdd_GetDevSize ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlSrvCfgHdd_GetDiskIndex ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlSrvCfgHdd_GetPartsCount ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlSrvCfgHdd_GetPart ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlSrvCfgHddPart_GetName ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlSrvCfgHddPart_GetSysName ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlSrvCfgHddPart_GetSize ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlSrvCfgHddPart_GetIndex ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlSrvCfgHddPart_GetType ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlSrvCfgHddPart_IsInUse ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlSrvCfgHddPart_IsLogical ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlSrvCfgHddPart_IsActive ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlSrvCfgNet_GetNetAdapterType ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlSrvCfgNet_GetSysIndex ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlSrvCfgNet_IsEnabled ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlSrvCfgNet_IsConfigureWithDhcp ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlSrvCfgNet_IsConfigureWithDhcpIPv6 ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlSrvCfgNet_GetDefaultGateway ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlSrvCfgNet_GetDefaultGatewayIPv6 ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlSrvCfgNet_GetMacAddress ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlSrvCfgNet_GetVlanTag ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlSrvCfgNet_GetNetAddresses ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlSrvCfgNet_GetDnsServers ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlSrvCfgNet_GetSearchDomains ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlSrvCfgPci_GetDeviceClass ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlSrvCfgPci_IsPrimaryDevice ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlUsrCfg_GetVmDirUuid ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlUsrCfg_SetVmDirUuid ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlUsrCfg_GetDefaultVmFolder ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlUsrCfg_SetDefaultVmFolder ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlUsrCfg_CanUseMngConsole ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlUsrCfg_CanChangeSrvSets ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlUsrCfg_IsLocalAdministrator ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlUsrInfo_GetName ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlUsrInfo_GetUuid ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlUsrInfo_GetSessionCount ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlUsrInfo_GetDefaultVmFolder ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlUsrInfo_CanChangeSrvSets ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlDispCfg_GetDefaultVmDir ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlDispCfg_GetDefaultCtDir ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlDispCfg_GetReservedMemLimit ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlDispCfg_SetReservedMemLimit ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlDispCfg_GetMinVmMem ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlDispCfg_SetMinVmMem ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlDispCfg_GetMaxVmMem ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlDispCfg_SetMaxVmMem ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlDispCfg_GetRecommendMaxVmMem ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlDispCfg_SetRecommendMaxVmMem ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlDispCfg_GetMaxReservMemLimit ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlDispCfg_SetMaxReservMemLimit ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlDispCfg_GetMinReservMemLimit ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlDispCfg_SetMinReservMemLimit ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlDispCfg_IsAdjustMemAuto ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlDispCfg_SetAdjustMemAuto ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlDispCfg_IsSendStatisticReport ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlDispCfg_SetSendStatisticReport ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlDispCfg_GetDefaultVNCHostName ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlDispCfg_SetDefaultVNCHostName ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlDispCfg_GetVNCBasePort ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlDispCfg_SetVNCBasePort ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlDispCfg_GetVNCMaxPort ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlDispCfg_CanChangeDefaultSettings ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlDispCfg_SetCanChangeDefaultSettings ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlDispCfg_GetMinSecurityLevel ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlDispCfg_SetMinSecurityLevel ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlDispCfg_GetConfirmationsList ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlDispCfg_SetConfirmationsList ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlDispCfg_GetDefaultBackupServer ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlDispCfg_SetDefaultBackupServer ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlDispCfg_GetBackupUserLogin ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlDispCfg_SetBackupUserLogin ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlDispCfg_SetBackupUserPassword ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlDispCfg_IsBackupUserPasswordEnabled ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlDispCfg_SetBackupUserPasswordEnabled ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlDispCfg_GetDefaultBackupDirectory ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlDispCfg_SetDefaultBackupDirectory ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlDispCfg_GetBackupTimeout ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlDispCfg_SetBackupTimeout ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlDispCfg_ArePluginsEnabled ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlDispCfg_EnablePlugins ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlDispCfg_GetVmCpuLimitType ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlDispCfg_SetVmCpuLimitType ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlDispCfg_IsVerboseLogEnabled ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlDispCfg_SetVerboseLogEnabled ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlDispCfg_IsAllowMultiplePMC ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlDispCfg_SetAllowMultiplePMC ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlDispCfg_IsLogRotationEnabled ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlDispCfg_SetLogRotationEnabled ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlDispCfg_GetCpuFeaturesMaskEx ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlDispCfg_SetCpuFeaturesMaskEx ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlCpuFeatures_Create ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlCpuFeatures_GetValue ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlCpuFeatures_SetValue ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVirtNet_Create ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVirtNet_GetNetworkId ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVirtNet_SetNetworkId ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVirtNet_GetDescription ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVirtNet_SetDescription ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVirtNet_GetNetworkType ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVirtNet_SetNetworkType ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVirtNet_GetBoundCardMac ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVirtNet_SetBoundCardMac ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVirtNet_GetAdapterName ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVirtNet_SetAdapterName ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVirtNet_GetAdapterIndex ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVirtNet_SetAdapterIndex ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVirtNet_GetHostIPAddress ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVirtNet_SetHostIPAddress ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVirtNet_GetHostIP6Address ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVirtNet_SetHostIP6Address ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVirtNet_GetDhcpIPAddress ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVirtNet_SetDhcpIPAddress ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVirtNet_GetDhcpIP6Address ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVirtNet_SetDhcpIP6Address ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVirtNet_GetIPNetMask ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVirtNet_SetIPNetMask ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVirtNet_GetIP6NetMask ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVirtNet_SetIP6NetMask ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVirtNet_GetVlanTag ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVirtNet_SetVlanTag ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVirtNet_GetIPScopeStart ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVirtNet_SetIPScopeStart ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVirtNet_GetIPScopeEnd ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVirtNet_SetIPScopeEnd ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVirtNet_GetIP6ScopeStart ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVirtNet_SetIP6ScopeStart ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVirtNet_GetIP6ScopeEnd ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVirtNet_SetIP6ScopeEnd ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVirtNet_IsEnabled ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVirtNet_SetEnabled ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVirtNet_IsAdapterEnabled ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVirtNet_SetAdapterEnabled ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVirtNet_IsDHCPServerEnabled ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVirtNet_SetDHCPServerEnabled ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVirtNet_IsDHCP6ServerEnabled ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVirtNet_SetDHCP6ServerEnabled ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVirtNet_IsNATServerEnabled ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVirtNet_SetNATServerEnabled ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVirtNet_GetPortForwardList ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVirtNet_SetPortForwardList ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVirtNet_GetBoundAdapterInfo ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlPortFwd_Create ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlPortFwd_GetRuleName ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlPortFwd_SetRuleName ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlPortFwd_GetIncomingPort ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlPortFwd_SetIncomingPort ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlPortFwd_GetRedirectIPAddress ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlPortFwd_SetRedirectIPAddress ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlPortFwd_GetRedirectPort ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlPortFwd_SetRedirectPort ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlPortFwd_GetRedirectVm ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlPortFwd_SetRedirectVm ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVm_Start ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVm_StartEx ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVm_Restart ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVm_Stop ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVm_StopEx ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVm_Pause ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVm_Reset ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVm_Suspend ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVm_ChangeSid ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVm_ResetUptime ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVm_GetSuspendedScreen ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVm_Resume ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVm_DropSuspendedState ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVm_CreateSnapshot ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVm_SwitchToSnapshot ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVm_SwitchToSnapshotEx ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVm_DeleteSnapshot ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVm_GetSnapshotsTree ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVm_GetSnapshotsTreeEx ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVm_Lock ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVm_Unlock ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVm_UpdateSnapshotData ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVm_Clone ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVm_CloneEx ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVm_CloneWithUuid ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVm_Migrate ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVm_MigrateEx ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVm_MigrateWithRename ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVm_MigrateWithRenameEx ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVm_MigrateCancel ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVm_GenerateVmDevFilename ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVm_Delete ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVm_GetProblemReport ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVm_GetPackedProblemReport ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVm_GetState ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVm_RefreshConfig ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVm_RefreshConfigEx ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVm_LoginInGuest ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVm_StartVncServer ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVm_StopVncServer ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmGuest_Logout ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmGuest_RunProgram ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmGuest_GetNetworkSettings ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVm_SetUserPasswd ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVm_SetConfig ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVm_GetConfig ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmCfg_SetDefaultConfig ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmCfg_IsConfigInvalid ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmCfg_GetConfigValidity ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmCfg_AddDefaultDevice ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmCfg_AddDefaultDeviceEx ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmCfg_IsDefaultDeviceNeeded ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmCfg_GetDefaultMemSize ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmCfg_GetDefaultHddSize ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmCfg_GetDefaultVideoRamSize ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVm_GetStatistics ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVm_GetStatisticsEx ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVm_SubscribeToGuestStatistics ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVm_UnsubscribeFromGuestStatistics ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVm_Reg ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVm_RegEx ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVm_Unreg ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVm_Restore ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVm_BeginEdit ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVm_Commit ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVm_CommitEx ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmCfg_CreateVmDev ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmCfg_GetAccessRights ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmCfg_GetDevsCount ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmCfg_GetAllDevices ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmCfg_GetDevsCountByType ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmCfg_GetDevByType ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmCfg_GetFloppyDisksCount ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmCfg_GetFloppyDisk ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmCfg_GetHardDisksCount ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmCfg_GetHardDisk ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmCfg_GetOpticalDisksCount ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmCfg_GetOpticalDisk ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmCfg_GetParallelPortsCount ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmCfg_GetParallelPort ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmCfg_GetSerialPortsCount ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmCfg_GetSerialPort ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmCfg_GetSoundDevsCount ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmCfg_GetSoundDev ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmCfg_GetUsbDevicesCount ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmCfg_GetUsbDevice ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmCfg_GetNetAdaptersCount ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmCfg_GetNetAdapter ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmCfg_GetGenericPciDevsCount ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmCfg_GetGenericPciDev ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmCfg_GetGenericScsiDevsCount ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmCfg_GetGenericScsiDev ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmCfg_GetDisplayDevsCount ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmCfg_GetDisplayDev ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmCfg_CreateShare ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmCfg_GetSharesCount ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmCfg_GetShare ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmCfg_IsSmartGuardEnabled ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmCfg_SetSmartGuardEnabled ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmCfg_IsSmartGuardNotifyBeforeCreation ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmCfg_SetSmartGuardNotifyBeforeCreation ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmCfg_GetSmartGuardInterval ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmCfg_SetSmartGuardInterval ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmCfg_GetSmartGuardMaxSnapshotsCount ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmCfg_SetSmartGuardMaxSnapshotsCount ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmCfg_IsUserDefinedSharedFoldersEnabled ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmCfg_SetUserDefinedSharedFoldersEnabled ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmCfg_IsSmartMountEnabled ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmCfg_SetSmartMountEnabled ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmCfg_IsSmartMountRemovableDrivesEnabled ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmCfg_SetSmartMountRemovableDrivesEnabled ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmCfg_IsSmartMountDVDsEnabled ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmCfg_SetSmartMountDVDsEnabled ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmCfg_IsSmartMountNetworkSharesEnabled ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmCfg_SetSmartMountNetworkSharesEnabled ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmCfg_IsSharedProfileEnabled ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmCfg_SetSharedProfileEnabled ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmCfg_IsUseDesktop ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmCfg_SetUseDesktop ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmCfg_IsUseDocuments ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmCfg_SetUseDocuments ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmCfg_IsUsePictures ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmCfg_SetUsePictures ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmCfg_IsUseMusic ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmCfg_SetUseMusic ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmCfg_IsUseDownloads ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmCfg_SetUseDownloads ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmCfg_IsUseMovies ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmCfg_SetUseMovies ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmCfg_GetOptimizeModifiersMode ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmCfg_SetOptimizeModifiersMode ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmCfg_IsShareClipboard ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmCfg_SetShareClipboard ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmCfg_IsOfflineManagementEnabled ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmCfg_SetOfflineManagementEnabled ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmCfg_IsToolsAutoUpdateEnabled) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmCfg_SetToolsAutoUpdateEnabled) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmCfg_IsTimeSynchronizationEnabled ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmCfg_SetTimeSynchronizationEnabled ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmCfg_IsTimeSyncSmartModeEnabled ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmCfg_SetTimeSyncSmartModeEnabled ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmCfg_GetTimeSyncInterval ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmCfg_SetTimeSyncInterval ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmCfg_IsAllowSelectBootDevice ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmCfg_SetAllowSelectBootDevice ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVm_RegEventHandler ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVm_UnregEventHandler ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVm_GetQuestions ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmCfg_CreateBootDev ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmCfg_GetBootDevCount ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmCfg_GetBootDev ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmCfg_GetName ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmCfg_SetName ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmCfg_GetHostname ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmCfg_SetHostname ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmCfg_GetDnsServers ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmCfg_SetDnsServers ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmCfg_GetUuid ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmCfg_SetUuid ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmCfg_GetCtId ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmCfg_GetLinkedVmUuid ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmCfg_GetOsType ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmCfg_GetOsVersion ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmCfg_SetOsVersion ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmCfg_GetRamSize ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmCfg_SetRamSize ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmCfg_GetVideoRamSize ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmCfg_SetVideoRamSize ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmCfg_GetMemGuaranteeSize ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmCfg_SetMemGuaranteeSize ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmCfg_GetCpuCount ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmCfg_SetCpuCount ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmCfg_GetCpuSocketsCount ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmCfg_SetCpuSocketsCount ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmCfg_GetCpuMode ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmCfg_SetCpuMode ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmCfg_GetCpuAccelLevel ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmCfg_SetCpuAccelLevel ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmCfg_IsCpuVtxEnabled ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmCfg_IsCpuHotplugEnabled ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmCfg_SetCpuHotplugEnabled ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmCfg_Get3DAccelerationMode ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmCfg_Set3DAccelerationMode ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmCfg_IsVerticalSynchronizationEnabled ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmCfg_SetVerticalSynchronizationEnabled ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmCfg_IsHighResolutionEnabled ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmCfg_SetHighResolutionEnabled ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmCfg_IsAdaptiveHypervisorEnabled ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmCfg_SetAdaptiveHypervisorEnabled ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmCfg_IsSwitchOffWindowsLogoEnabled ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmCfg_SetSwitchOffWindowsLogoEnabled ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmCfg_IsLongerBatteryLifeEnabled ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmCfg_SetLongerBatteryLifeEnabled ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmCfg_IsBatteryStatusEnabled ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmCfg_SetBatteryStatusEnabled ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmCfg_IsNestedVirtualizationEnabled ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmCfg_SetNestedVirtualizationEnabled ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmCfg_IsPMUVirtualizationEnabled ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmCfg_SetPMUVirtualizationEnabled ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmCfg_IsLockGuestOnSuspendEnabled ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmCfg_SetLockGuestOnSuspendEnabled ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmCfg_IsIsolatedVmEnabled ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmCfg_SetIsolatedVmEnabled ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmCfg_SetCpuUnits ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmCfg_GetCpuUnits ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmCfg_SetCpuLimit ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmCfg_GetCpuLimit ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmCfg_SetCpuLimitEx ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmCfg_GetCpuLimitEx ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmCfg_GetCpuMask ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmCfg_SetCpuMask ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmCfg_GetNodeMask ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmCfg_SetNodeMask ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmCfg_GetIoPriority ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmCfg_SetIoPriority ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmCfg_GetIoLimit ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmCfg_SetIoLimit ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmCfg_GetIopsLimit ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmCfg_SetIopsLimit ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmCfg_GetServerUuid ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmCfg_GetServerHost ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmCfg_GetHomePath ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmCfg_GetLocation ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmCfg_GetIcon ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmCfg_SetIcon ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmCfg_GetDescription ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmCfg_SetDescription ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmCfg_IsTemplate ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmCfg_SetTemplateSign ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmCfg_GetCustomProperty ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmCfg_SetCustomProperty ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmCfg_GetAutoStart ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmCfg_SetAutoStart ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmCfg_GetAutoStartDelay ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmCfg_SetAutoStartDelay ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmCfg_GetStartLoginMode ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmCfg_SetStartLoginMode ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmCfg_GetStartUserLogin ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmCfg_SetStartUserCreds ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmCfg_GetAutoStop ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmCfg_SetAutoStop ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmCfg_GetActionOnWindowClose ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmCfg_SetActionOnWindowClose ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmCfg_GetActionOnStopMode ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmCfg_SetActionOnStopMode ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmCfg_GetWindowMode ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmCfg_SetWindowMode ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmCfg_IsStartInDetachedWindowEnabled ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmCfg_SetStartInDetachedWindowEnabled ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmCfg_IsLockInFullScreenMode ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmCfg_SetLockInFullScreenMode ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmCfg_GetLastModifiedDate ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmCfg_GetLastModifierName ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmCfg_GetUptimeStartDate ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmCfg_GetUptime ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmCfg_IsGuestSharingEnabled ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmCfg_SetGuestSharingEnabled ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmCfg_IsGuestSharingAutoMount ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmCfg_SetGuestSharingAutoMount ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmCfg_IsGuestSharingEnableSpotlight ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmCfg_SetGuestSharingEnableSpotlight ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmCfg_IsHostSharingEnabled ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmCfg_SetHostSharingEnabled ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmCfg_IsShareAllHostDisks ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmCfg_SetShareAllHostDisks ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmCfg_IsShareUserHomeDir ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmCfg_SetShareUserHomeDir ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmCfg_IsMapSharedFoldersOnLetters ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmCfg_SetMapSharedFoldersOnLetters ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmCfg_GetVNCMode ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmCfg_SetVNCMode ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmCfg_GetVNCPassword ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmCfg_SetVNCPassword ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmCfg_GetVNCHostName ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmCfg_SetVNCHostName ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmCfg_GetVNCPort ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmCfg_SetVNCPort ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmCfg_GetVNCWebSocketPort ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmCfg_IsVNCEncryptionEnabled ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmCfg_IsScrResEnabled ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmCfg_SetScrResEnabled ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmCfg_IsDiskCacheWriteBack ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmCfg_SetDiskCacheWriteBack ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmCfg_IsOsResInFullScrMode ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmCfg_SetOsResInFullScrMode ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmCfg_IsCloseAppOnShutdown ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmCfg_SetCloseAppOnShutdown ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmCfg_GetSystemFlags ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmCfg_SetSystemFlags ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmCfg_IsDisableAPIC ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmCfg_SetDisableAPICSign ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmCfg_IsDisableSpeaker ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmCfg_SetDisableSpeakerSign ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmCfg_GetUndoDisksMode ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmCfg_SetUndoDisksMode ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmCfg_GetForegroundPriority ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmCfg_SetForegroundPriority ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmCfg_GetBackgroundPriority ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmCfg_SetBackgroundPriority ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmCfg_IsUseDefaultAnswers ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmCfg_SetUseDefaultAnswers ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmCfg_GetSearchDomains ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmCfg_SetSearchDomains ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmCfg_GetOfflineServices ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmCfg_SetOfflineServices ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmCfg_GetConfirmationsList ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmCfg_SetConfirmationsList ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmCfg_IsAutoCompressEnabled ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmCfg_SetAutoCompressEnabled ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmCfg_GetAutoCompressInterval ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmCfg_SetAutoCompressInterval ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmCfg_GetFreeDiskSpaceRatio ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmCfg_SetFreeDiskSpaceRatio ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmCfg_GetVmInfo ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmCfg_GetVmType ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmCfg_SetVmType ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmCfg_IsEfiEnabled ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmCfg_SetEfiEnabled ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmCfg_GetExternalBootDevice ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmCfg_SetExternalBootDevice ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVm_CreateEvent ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVm_CreateUnattendedFloppy ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlSrv_CreateUnattendedCd ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVm_InitiateDevStateNotifications ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVm_ValidateConfig ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVm_UpdateSecurity ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVm_InstallTools ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVm_GetToolsState ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmDev_Create ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmDev_Connect ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmDev_Disconnect ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmDev_CreateImage ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmDev_CopyImage ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmDev_ResizeImage ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmDev_GetIndex ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmDev_SetIndex ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmDev_Remove ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmDev_GetType ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmDev_IsConnected ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmDev_SetConnected ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmDev_IsEnabled ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmDev_SetEnabled ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmDev_IsRemote ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmDev_SetRemote ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmDev_GetEmulatedType ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmDev_SetEmulatedType ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmDev_GetImagePath ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmDev_SetImagePath ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmDev_GetSysName ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmDev_SetSysName ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmDev_GetFriendlyName ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmDev_SetFriendlyName ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmDev_GetDescription ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmDev_SetDescription ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmDev_GetIfaceType ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmDev_SetIfaceType ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmDev_GetSubType ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmDev_SetSubType ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmDev_GetStackIndex ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmDev_SetStackIndex ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmDev_SetDefaultStackIndex ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmDev_GetOutputFile ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmDev_SetOutputFile ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmDev_IsPassthrough ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmDev_SetPassthrough ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmDevHd_GetDiskType ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmDevHd_SetDiskType ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmDevHd_IsSplitted ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmDevHd_SetSplitted ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmDevHd_GetDiskSize ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmDevHd_SetDiskSize ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmDevHd_GetSizeOnDisk ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmDevHd_AddPartition ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmDevHd_GetPartitionsCount ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmDevHd_GetPartition ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmDevHdPart_Remove ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmDevHd_SetMountPoint ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmDevHd_GetMountPoint ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmDevHd_SetAutoCompressEnabled ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmDevHd_IsAutoCompressEnabled ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmDevHd_SetStorageURL ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmDevHd_GetStorageURL ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmDevHd_GetEncryption ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmDevHd_SetEncryption ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmDevHd_GetSerialNumber ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmDevHd_SetSerialNumber ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmDevHdPart_GetSysName ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmDevHdPart_SetSysName ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmDevHdEncryption_GetKeyId ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmDevHdEncryption_SetKeyId ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmDevNet_GetBoundAdapterIndex ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmDevNet_SetBoundAdapterIndex ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmDevNet_GetBoundAdapterName ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmDevNet_SetBoundAdapterName ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmDevNet_GetMacAddress ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmDevNet_GetMacAddressCanonical ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmDevNet_SetMacAddress ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmDevNet_GenerateMacAddr ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmDevNet_IsAutoApply ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmDevNet_SetAutoApply ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmDevNet_GetNetAddresses ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmDevNet_SetNetAddresses ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmDevNet_GetDnsServers ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmDevNet_SetDnsServers ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmDevNet_GetSearchDomains ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmDevNet_SetSearchDomains ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmDevNet_IsConfigureWithDhcp ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmDevNet_SetConfigureWithDhcp ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmDevNet_IsConfigureWithDhcpIPv6 ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmDevNet_SetConfigureWithDhcpIPv6 ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmDevNet_GetDefaultGateway ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmDevNet_SetDefaultGateway ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmDevNet_GetDefaultGatewayIPv6 ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmDevNet_SetDefaultGatewayIPv6 ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmDevNet_GetVirtualNetworkId ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmDevNet_SetVirtualNetworkId ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmDevNet_GetAdapterType ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmDevNet_SetAdapterType ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmDevNet_IsPktFilterPreventMacSpoof ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmDevNet_SetPktFilterPreventMacSpoof) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmDevNet_IsPktFilterPreventPromisc ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmDevNet_SetPktFilterPreventPromisc ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmDevNet_IsPktFilterPreventIpSpoof ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmDevNet_SetPktFilterPreventIpSpoof ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmDevNet_IsFirewallEnabled ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmDevNet_SetFirewallEnabled ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmDevNet_GetFirewallDefaultPolicy ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmDevNet_SetFirewallDefaultPolicy ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmDevNet_GetFirewallRuleList ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmDevNet_SetFirewallRuleList ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmDevNet_GetHostInterfaceName ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmDevNet_SetHostInterfaceName ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlFirewallRule_Create ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlFirewallRule_GetLocalPort ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlFirewallRule_SetLocalPort ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlFirewallRule_GetRemotePort ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlFirewallRule_SetRemotePort ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlFirewallRule_GetProtocol ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlFirewallRule_SetProtocol ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlFirewallRule_GetLocalNetAddress ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlFirewallRule_SetLocalNetAddress ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlFirewallRule_GetRemoteNetAddress ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlFirewallRule_SetRemoteNetAddress ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmDevUsb_GetAutoconnectOption ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmDevUsb_SetAutoconnectOption ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmDevSound_GetOutputDev ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmDevSound_SetOutputDev ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmDevSound_GetMixerDev ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmDevSound_SetMixerDev ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmDevSerial_GetSocketMode ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmDevSerial_SetSocketMode ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlShare_Remove ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlShare_GetName ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlShare_SetName ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlShare_GetPath ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlShare_SetPath ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlShare_GetDescription ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlShare_SetDescription ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlShare_IsEnabled ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlShare_SetEnabled ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlShare_IsReadOnly ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlShare_SetReadOnly ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlBootDev_Remove ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlBootDev_GetType ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlBootDev_SetType ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlBootDev_GetIndex ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlBootDev_SetIndex ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlBootDev_GetSequenceIndex ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlBootDev_SetSequenceIndex ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlBootDev_IsInUse ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlBootDev_SetInUse ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmInfo_GetState ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmInfo_GetAccessRights ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmInfo_IsInvalid ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmInfo_IsVmWaitingForAnswer ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmInfo_IsVncServerStarted ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlFoundVmInfo_GetName ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlFoundVmInfo_IsOldConfig ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlFoundVmInfo_GetOSVersion ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlFoundVmInfo_GetConfigPath ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlFoundVmInfo_IsTemplate ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlAcl_IsAllowed ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlAcl_GetAccessForOthers ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlAcl_SetAccessForOthers ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlAcl_GetOwnerName ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlAcl_IsCurrentSessionOwner ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmToolsInfo_GetState ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmToolsInfo_GetVersion ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlStat_GetTotalRamSize )	\
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlStat_GetUsageRamSize ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlStat_GetFreeRamSize ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlStat_GetRealRamSize ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlStat_GetOsUptime ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlStat_GetCpusStatsCount ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlStat_GetCpuStat ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlStatCpu_GetCpuUsage ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlStatCpu_GetTotalTime ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlStatCpu_GetUserTime ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlStatCpu_GetSystemTime ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlLic_IsValid ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlLic_GetStatus ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlLic_GetLicenseKey ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlLic_GetUserName ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlLic_GetCompanyName ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlSrvInfo_GetHostName ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlSrvInfo_GetOsVersion ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlSrvInfo_GetProductVersion ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlSrvInfo_GetCmdPort ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlSrvInfo_GetApplicationMode ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlSrvInfo_GetServerUuid ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlSrvInfo_GetStartTime ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlSrvInfo_GetStartTimeMonotonic ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlNetSvc_GetStatus ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlSrv_FsGenerateEntryName ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlLoginResponse_GetSessionUuid ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlLoginResponse_GetRunningTaskCount ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlLoginResponse_GetRunningTaskByIndex ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlLoginResponse_GetServerUuid ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlLoginResponse_GetHostOsVersion ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlLoginResponse_GetProductVersion ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlRunningTask_GetTaskUuid ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlRunningTask_GetTaskType ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlRunningTask_GetTaskParametersAsString ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlSrv_SubscribeToPerfStats )     \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlSrv_UnsubscribeFromPerfStats ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlSrv_GetPerfStats )             \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVm_SubscribeToPerfStats )      \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVm_UnsubscribeFromPerfStats )  \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVm_GetPerfStats ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVm_AuthWithGuestSecurityDb ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmInfo_GetAdditionState ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVm_Compact ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVm_CancelCompact ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVm_ConvertDisks ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVm_CancelConvertDisks ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlOsesMatrix_GetSupportedOsesTypes ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlOsesMatrix_GetSupportedOsesVersions ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlOsesMatrix_GetDefaultOsVersion ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlOsesMatrix_GetSupportType ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlSrv_HasRestriction ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlSrv_GetRestrictionInfo ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlApi_CreateProblemReport ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlReport_SetUserName ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlReport_GetUserName ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlReport_SetUserEmail ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlReport_GetUserEmail ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlReport_SetDescription ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlReport_GetDescription ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlReport_SetType ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlReport_GetType ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlReport_SetReason ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlReport_GetReason ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlReport_GetScheme ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlReport_GetArchiveFileName ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlReport_GetData ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlReport_AsString ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlReport_Assembly ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlReport_Send ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlSrv_InstallAppliance ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlSrv_CancelInstallAppliance ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlSrv_StopInstallAppliance ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlAppliance_Create ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlCtTemplate_GetName ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlCtTemplate_GetType ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlCtTemplate_GetDescription ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlCtTemplate_GetVersion ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlCtTemplate_GetOsType ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlCtTemplate_GetOsVersion ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlCtTemplate_GetOsTemplate ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlCtTemplate_GetCpuMode ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlCtTemplate_IsCached ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlSrv_GetCtTemplateList ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlSrv_RemoveCtTemplate ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlDispCfg_GetUsbIdentityCount ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlDispCfg_GetUsbIdentity ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlUsbIdent_GetSystemName ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlUsbIdent_GetFriendlyName ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlUsbIdent_GetVmUuidAssociation ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlDispCfg_SetUsbIdentAssociation ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlSrv_CopyCtTemplate ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlSrv_IsFeatureSupported ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlSrv_AddIPPrivateNetwork ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlSrv_RemoveIPPrivateNetwork ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlSrv_UpdateIPPrivateNetwork ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlSrv_GetIPPrivateNetworksList ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlIPPrivNet_Create ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlIPPrivNet_GetName ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlIPPrivNet_SetNetAddresses ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlIPPrivNet_GetNetAddresses ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlIPPrivNet_SetName ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlIPPrivNet_IsGlobal ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlIPPrivNet_SetGlobal ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmCfg_IsRamHotplugEnabled ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmCfg_SetRamHotplugEnabled ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlSrv_RefreshPlugins ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlSrv_GetPluginsList ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVm_Mount ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVm_Umount ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlPluginInfo_GetVendor ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlPluginInfo_GetCopyright ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlPluginInfo_GetShortDescription ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlPluginInfo_GetLongDescription ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlPluginInfo_GetVersion ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlPluginInfo_GetId ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlSrv_LoginEx ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlSrv_LoginLocalEx ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlHandle_RegEventHandler ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlHandle_UnregEventHandler ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlSrv_GetDiskFreeSpace ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlBackupResult_GetBackupUuid ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVm_Move ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVm_Connect ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVm_Disconnect ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlSrv_GetVmConfig ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmCfg_GetResource ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmCfg_SetResource ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmCfg_IsAutoApplyIpOnly) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmCfg_SetAutoApplyIpOnly) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmCfg_GetCapabilitiesMask ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmCfg_SetCapabilitiesMask ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmCfg_GetNetfilterMode ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmCfg_SetNetfilterMode ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlHandle_GetPackageId ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlSrv_GetCPUPoolsList ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlSrv_MoveToCPUPool ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlSrv_RecalculateCPUPool ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlDispCfg_GetCpuPool ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlCPUPool_GetVendor ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlCPUPool_GetName ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlCPUPool_GetCpuFeaturesMask ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmCfg_GetFeaturesMask ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmCfg_SetFeaturesMask ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlSrv_SendProblemReport ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlHandle_FromString ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlHandle_ToString ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlEvent_FromString ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlApi_SwitchConsoleLogging ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmCfg_SetHighAvailabilityEnabled ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmCfg_IsHighAvailabilityEnabled ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmCfg_SetHighAvailabilityPriority ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmCfg_GetHighAvailabilityPriority ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlDisk_CreateDisk_Local ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlDisk_OpenDisk_Local ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlDisk_WaitForCompletion ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlDisk_SwitchToState ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlDisk_Write ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlDisk_Read ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlDisk_GetDiskInfo ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlDiskMap_GetSize ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlDiskMap_GetGranularity ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlDiskMap_Read ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlDisk_FlushCache ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlDisk_GetChangesMap_Local ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlDisk_Free ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVm_CaptureScreen ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVm_CommitEncryption ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmCfg_GetActionOnGuestCrash ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmCfg_SetActionOnGuestCrash ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmCfg_GetOptionsOnGuestCrash ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmCfg_SetOptionsOnGuestCrash ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlSrv_GetVcmmdConfig ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlSrv_SetVcmmdConfig ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVcmmdConfig_SetPolicy ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVcmmdConfig_GetPolicy ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlCt_Reinstall ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlApi_GuestToString ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVm_BeginBackup ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmBackup_Commit ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmBackup_Rollback ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmBackup_GetDisksCount ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmBackup_GetUuid ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmBackup_GetDisk ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmCfg_GetDefaultBackupDirectory ) \
PRL_SDK_WRAP_FOR_EACH_ITERATOR( PrlVmCfg_SetDefaultBackupDirectory ) \

#endif // PRL_SDK_WRAP_FOR_EACH
