/*
 * PrlApiVersion.h
 *
 * Copyright (c) 2006-2021, Parallels International GmbH
 *
 * This file is part of Virtuozzo SDK. Virtuozzo SDK is free
 * software; you can redistribute it and/or modify it under the
 * terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation; either version 2.1 of the License,
 * or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library.  If not, see
 * <http://www.gnu.org/licenses/> or write to Free Software Foundation,
 * 51 Franklin Street, Fifth Floor Boston, MA 02110, USA.
 *
 * Our contact details: Virtuozzo International GmbH, Vordergasse 59, 8200
 * Schaffhausen, Switzerland; http://www.virtuozzo.com/.
 */


#ifndef __PRLAPIVERSION_H__
#define __PRLAPIVERSION_H__

/* Converts major and minor versions of the API to the format
   understood by SDK library. */
#define TO_VIRTUOZZO_API_VER(majorV, minorV) \
     ((PRL_UINT32)(((PRL_UINT32)majorV) << 16 | ((PRL_UINT16)minorV)))

/* Converts API version from the library native format to
   major and minor values. */
#define FROM_VIRTUOZZO_API_VER(version, majorV, minorV) \
     majorV = ((PRL_UINT32)version) >> 16; \
     minorV = ((PRL_UINT32)version) & 0x0000FFFF


#define VIRTUOZZO_API_VER_1 TO_VIRTUOZZO_API_VER(0,1)
#define VIRTUOZZO_API_VER_2 TO_VIRTUOZZO_API_VER(2,0)
#define VIRTUOZZO_API_VER_3 TO_VIRTUOZZO_API_VER(3,0)
#define VIRTUOZZO_API_VER_4 TO_VIRTUOZZO_API_VER(4,0)
#define VIRTUOZZO_API_VER_5 TO_VIRTUOZZO_API_VER(5,0)
#define VIRTUOZZO_API_VER_6 TO_VIRTUOZZO_API_VER(6,0)
#define VIRTUOZZO_API_VER_7 TO_VIRTUOZZO_API_VER(7,0)

/* Current API version. */
#define VIRTUOZZO_API_VER VIRTUOZZO_API_VER_7

/* Current major version of SDK library */
#define VIRTUOZZO_SDK_LIB_MAJ "7"

#endif // __PRLAPIVERSION_H__

